pub enum JsonRpcTransportRecvError {
UnexpectedServerResponse(Message),
PayloadRecvError(Error),
PayloadParseError(Broken),
ResponseParseError(JsonRpcTransportHandlerResponseError),
}Expand description
Potential errors returned while receiving responses from an RPC server.
Variants
UnexpectedServerResponse(Message)
Client receives a JSON RPC message body that isn’t structured as a response.
PayloadRecvError(Error)
Client is unable to read the response from the RPC server.
PayloadParseError(Broken)
The base response structure is malformed e.g. meta properties like RPC version are missing.
ResponseParseError(JsonRpcTransportHandlerResponseError)
Potential errors returned when the client has an issue parsing the response of a method call.